@@ -473,6 +473,9 @@ reloadData = function(
 #'   levels, and numeric columns should have the same or smaller range,
 #'   otherwise the filters may never be able to reach certain rows in the data,
 #'   unless you explicitly update the filters with \code{updateFilters()}.
+#'
+#'   If the \code{ColReorder} extension is used, the new \code{data} must have
+#'   column names that match the original data column names exactly.
 #' @export
 replaceData = function(proxy, data, ..., resetPaging = TRUE, clearSelection = 'all') {
   dataTableAjax(proxy$session, data, ..., outputId = proxy$rawId)
@@ -614,10 +617,25 @@ dataTablesFilter = function(data, params) {
     DT_rows_current = list()
   ))
 
+  # map DataTables's column index in the query (`i` here) to the actual column
+  # index in data via its name because the two indices won't match when columns
+  # are reordered via the colReorder extension
+  imap = unlist(lapply(q$columns, function(col) {
+    # if data doesn't have column names (e.g., #1108), assume it's not reordered
+    # (which may not be true)
+    if (is.null(names(data))) return(0L)
+    k = col[['name']]
+    if (!is.character(k) || k == '') return(0L)
+    i = match(k, names(data))
+    if (is.na(i)) stop("The column name '", k, "' is not found in data.")
+    i
+  }))
+  if (all(imap == 0)) imap[] = seq_len(ncol(data))
+
   # which columns are searchable?
   searchable = logical(ncol(data))
-  for (j in seq_len(ncol(data))) {
-    if (q$columns[[j]][['searchable']] == 'true') searchable[j] = TRUE
+  for (j in names(q$columns)) {
+    if (q$columns[[j]][['searchable']] == 'true') searchable[imap[j]] = TRUE
   }
 
   # global searching options (column search shares caseInsensitive)
@@ -631,19 +649,25 @@ dataTablesFilter = function(data, params) {
   # start searching with all rows
   i = seq_len(n)
 
+  # apply SearchBuilder query if present
+  if (!is.null(s <- q$searchBuilder)) {
+    r = sbEvaluateSearch(s, data)
+    if (!is.null(r)) i = which(r)
+  }
+
   # search by columns
   if (length(i)) for (j in names(q$columns)) {
     col = q$columns[[j]]
+    j = imap[j]
     # if the j-th column is not searchable or the search string is "", skip it
-    if (col[['searchable']] != 'true') next
+    if (!searchable[j]) next
     if ((k <- col[['search']][['value']]) == '') next
     k = httpuv::decodeURIComponent(k)
     column_opts = list(
       regex = col[['search']][['regex']] != 'false',
       caseInsensitive = global_opts$caseInsensitive
     )
-    j = as.integer(j)
-    dj = data[i, j + 1]
+    dj = data[i, j]
     i = i[doColumnSearch(dj, k, options = column_opts)]
     if (length(i) == 0) break
   }
@@ -664,7 +688,7 @@ dataTablesFilter = function(data, params) {
     k = ord[['column']]  # which column to sort
     d = ord[['dir']]     # direction asc/desc
     if (q$columns[[k]][['orderable']] != 'true') next
-    col = data[, as.integer(k) + 1]
+    col = data[, imap[k]]
     oList[[length(oList) + 1]] = (if (d == 'asc') identity else `-`)(
       if (is.numeric(col)) col else xtfrm(col)
     )
