@@ -11,7 +11,7 @@ isFALSE = function(x) identical(x, FALSE)
 
 is.Date = function(x) inherits(x, c('Date', 'POSIXlt', 'POSIXct'))
 
-# for CSS propertices: fontWeight -> font-weight, backgroundColor ->
+# for CSS properties: fontWeight -> font-weight, backgroundColor ->
 # background-color, etc
 upperToDash = function(x) {
   x = gsub('^(.)', '\\L\\1', x, perl = TRUE)
@@ -20,8 +20,7 @@ upperToDash = function(x) {
 }
 
 inShiny = function() {
-  getOption('DT.datatable.shiny', FALSE) ||
-    ('shiny' %in% loadedNamespaces() && !is.null(shiny::getDefaultReactiveDomain()))
+  getOption('DT.datatable.shiny', 'shiny' %in% loadedNamespaces())
 }
 
 in_dir = function(dir, expr) {
